@@ -67,40 +67,45 @@ class QuestionServiceRestInterceptor:
 
     .. code-block:: python
         class MyCustomQuestionServiceInterceptor(QuestionServiceRestInterceptor):
-            def pre_create_question(request, metadata):
+            def pre_create_question(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_create_question(response):
+            def post_create_question(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_execute_question(request, metadata):
+            def pre_execute_question(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_execute_question(response):
+            def post_execute_question(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_question(request, metadata):
+            def pre_get_question(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_question(response):
+            def post_get_question(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_user_feedback(request, metadata):
+            def pre_get_user_feedback(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_user_feedback(response):
+            def post_get_user_feedback(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_update_user_feedback(request, metadata):
+            def pre_update_user_feedback(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_update_user_feedback(response):
+            def post_update_user_feedback(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = QuestionServiceRestTransport(interceptor=MyCustomQuestionServiceInterceptor())
         client = QuestionServiceClient(transport=transport)
@@ -263,10 +268,10 @@ class QuestionServiceRestTransport(QuestionServiceTransport):
         self,
         *,
         host: str = "dataqna.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -358,7 +363,7 @@ class QuestionServiceRestTransport(QuestionServiceTransport):
             request: question_service.CreateQuestionRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> gcd_question.Question:
             r"""Call the create question method over HTTP.
@@ -458,7 +463,7 @@ class QuestionServiceRestTransport(QuestionServiceTransport):
             request: question_service.ExecuteQuestionRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> question.Question:
             r"""Call the execute question method over HTTP.
@@ -558,7 +563,7 @@ class QuestionServiceRestTransport(QuestionServiceTransport):
             request: question_service.GetQuestionRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> question.Question:
             r"""Call the get question method over HTTP.
@@ -649,7 +654,7 @@ class QuestionServiceRestTransport(QuestionServiceTransport):
             request: question_service.GetUserFeedbackRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> user_feedback.UserFeedback:
             r"""Call the get user feedback method over HTTP.
@@ -735,7 +740,7 @@ class QuestionServiceRestTransport(QuestionServiceTransport):
             request: question_service.UpdateUserFeedbackRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> gcd_user_feedback.UserFeedback:
             r"""Call the update user feedback method over HTTP.
